import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
import { initData } from '@/api/data'
/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/test',
    component: () => import('@/views/test/index'),
    hidden: true,
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true,
  },
  {
    path: '/error',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/404',
        component: () => import('@/views/features/404'),
      },
      {
        path: '/401',
        component: () => import('@/views/features/401'),
      },
    ],
  },
  // {
  //   path: '/404',
  //   component: () => import('@/views/features/404'),
  //   hidden: true,
  // },
  {
    path: '/dashboard',
    redirect: '/main',
    component: Layout,
    hidden: true,
  },
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path*',
        component: () => import('@/views/features/redirect'),
      },
    ],
  },
  {
    path: '/',
    component: Layout,
    redirect: '/main',
    children: [
      {
        path: 'main',
        name: 'Main',
        component: () => import('@/views/main/index'),
        meta: { title: '首页', icon: 'home' },
      },
    ],
    // redirect: '/positioning/map',
    // children: [
    //   {
    //     path: 'positioning/map',
    //     name: 'Map',
    //     component: () => import('@/views/positioning/map/index'),
    //     meta: { title: '首页', icon: 'dashboard' }
    //   }
    // ]
  },
  {
    path: '/center',
    component: Layout,
    hidden: true,
    redirect: '/noredirect',
    children: [
      {
        path: 'message',
        component: () => import('@/views/system/message/index'),
        name: 'Message',
        meta: { title: '系统消息' },
      },
    ],
  },
  {
    path: '/alarmDetail',
    component: Layout,
    redirect: '/alarmDetail',
    hidden: true,
    children: [
      {
        path: '/alarmDetail/:id',
        name: 'alarmDetail',
        component: () => import('@/views/alarmDetail/index'),
        meta: { title: '报警详情' },
      },
    ],
  },
]

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes,
  })

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
